## Kurulum

### Proje ortamına kurulumu

```html
<script src="https://ws.saqut.com/script"></script>
```

### Geliştirme ortamına kurulumu

```javascript
const wsjs = new MWSE({
    endpoint: "https://ws.saqut.com/"    // MSWS kurulu sunucu adresi
});
wsjs.scope(async () => {
    // Bağlantı sağlandığında burası tetiklenir
})
```

### Kendi bağlantı kimliğini öğrenme

```javascript
wsjs.scope(async () => {
    let me = wsjs.peer('me');   // Kendi bağlantınız üzerinde işlem yaparken `me` olarak bahsedersiniz
    console.log(me.socketId);   // Her eşin tekil bir socketIdsi vardır
})
```


### Sanal Adres ayırma / yeniden ayırma / kaldırma
```javascript
wsjs.scope(async () => {
    let me = wsjs.peer('me');

    /**
     * Sanal adresler size veri gönderilmek istendiğinde veya etkileşime
     * geçilmesi istendiğinde ona socketId gibi bir UUID yerine sizi temsil eden daha kısa
     * ip adresi, sayı veya kısa bir kod ile aynı şeyleri yapmanıza olanak tanır.
     * Aynı anda hem sanal ip adres, sayı ve kısa koduna sahip olabilirsiniz
     * ancak aynı türden temsil koduna (mesela kısa koddan) birden fazla sahip olamazsınız
     * Yeni bir bağlantı daha açmanız gerekir
     **/

    // Bağlantınıze özel sanal tekil ip adresi kaynağı ayırın
    let ipadress = await me.virtualPressure.allocAPIPAddress();

    // Bağlantınıze özel sanal tekil numara kaynağı ayırın
    let numberaddress = await me.virtualPressure.allocAPNumber();

    // Bağlantınıze özel sanal kod kaynağı ayırın
    let shortcodeadress = await me.virtualPressure.allocAPShortCode();

    // Bütün bu kaynakları yenileriyle değiştirmek için
    // her birinin ayrı ayrı yeniden alma işlevleri vardır
    // Bir adresi yenilediğinizde artık eski adres kullanılmaz olur
    me.virtualPressure.reallocAPIPAddress();
    me.virtualPressure.reallocAPNumber();
    me.virtualPressure.reallocAPShortCode();

    // Bütün bu kaynakları kaldırmak için  her birinin ayrı ayrı
    // bırakma işlevi vardır
    // Bir adresi kullanmadığınızda artık bu adreslerden size
    // ulaşılamaz olursunuz
    await me.virtualPressure.releaseAPIPAddress();
    await me.virtualPressure.releaseAPNumber();
    await me.virtualPressure.releaseAPShortCode();

    await me.virtualPressure.queryAPIPAddress();
    await me.virtualPressure.queryAPNumber();
    await me.virtualPressure.queryAPShortCode();
})
```

Farklı bir eş ile iletişime geçme

```javascript
wsjs.scope(async () => {
    let peer = wsjs.peer('325a8f7f-eaaf-4c21-855e-9e965c0d5ac9')   // Diğer eşin socketId'sini belirtiyoruz

    peer.on('message',(payload) => {
        // Eş eğer mesaj gönderirse burası tetiklenecek ve gönderdiği mesaj payload değişkeni ile iletilir
    })
    // Mesaj göndermek için send fonksiyonunu kullanabilirsiniz
    peer.send('Merhaba');
    peer.send([29, true]);
    peer.send({
        type: 'notification',
        value: "Hi!"
    });
})
```